@@ -26,7 +26,8 @@ class SmsClient(AbstractClient):
 
 
     def AddSmsSign(self, request):
-        """This API is used to add an SMS signature.
+        """This API is used to add an SMS signature. Please read the [Tencent Cloud SMS Signature Review Standards](https://cloud.tencent.com/document/product/382/39022) before starting an application.
+        >⚠️ Note: individual users cannot use this API to apply for SMS signatures. For more information, please see [Identity Verification Overview](https://cloud.tencent.com/document/product/378/3629). If your account identity is individual, please log in to the console to apply for SMS signatures. For detailed directions, please see [Creating SMS Signatures](https://cloud.tencent.com/document/product/382/36136#Sign).
 
         :param request: Request instance for AddSmsSign.
         :type request: :class:`tencentcloud.sms.v20190711.models.AddSmsSignRequest`
@@ -54,7 +55,8 @@ class SmsClient(AbstractClient):
 
 
     def AddSmsTemplate(self, request):
-        """This API is used to add an SMS template.
+        """This API is used to add an SMS template. Please read the [Tencent Cloud SMS Body Template Review Standards](https://cloud.tencent.com/document/product/382/39023) before starting an application.
+        >⚠️ Note: individual users cannot use this API to apply for SMS body templates. For more information, please see [Identity Verification Overview](https://cloud.tencent.com/document/product/378/3629). If your account identity is individual, please log in to the console to apply for SMS body templates. For detailed directions, please see [Creating SMS Body Templates](https://cloud.tencent.com/document/product/382/36136#Template).
 
         :param request: Request instance for AddSmsTemplate.
         :type request: :class:`tencentcloud.sms.v20190711.models.AddSmsTemplateRequest`
@@ -110,7 +112,7 @@ class SmsClient(AbstractClient):
 
 
     def DeleteSmsSign(self, request):
-        """This API is used to delete an SMS signature.
+        """>⚠️ Note: individual users cannot use this API to delete SMS signatures. For more information, please see [Identity Verification Overview](https://cloud.tencent.com/document/product/378/3629). You can log in to the console to delete SMS signatures. For detailed directions, please see the notes on deleting SMS signatures in [SMS Signature Operations](https://cloud.tencent.com/document/product/382/36136#Sign).
 
         :param request: Request instance for DeleteSmsSign.
         :type request: :class:`tencentcloud.sms.v20190711.models.DeleteSmsSignRequest`
@@ -138,7 +140,7 @@ class SmsClient(AbstractClient):
 
 
     def DeleteSmsTemplate(self, request):
-        """This API is used to delete an SMS template.
+        """>⚠️ Note: individual users cannot use this API to delete SMS body templates. For more information, please see [Identity Verification Overview](https://cloud.tencent.com/document/product/378/3629). You can log in to the console to delete SMS body templates. For detailed directions, please see the notes on deleting SMS body templates in [SMS Body Template Operations](https://cloud.tencent.com/document/product/382/36136#Template).
 
         :param request: Request instance for DeleteSmsTemplate.
         :type request: :class:`tencentcloud.sms.v20190711.models.DeleteSmsTemplateRequest`
@@ -166,7 +168,7 @@ class SmsClient(AbstractClient):
 
 
     def DescribeSmsSignList(self, request):
-        """>⚠️注意：个人认证用户不支持使用 API 查询短信签名，请参阅了解 [实名认证基本介绍](https://cloud.tencent.com/document/product/378/3629)。
+        """>⚠️ Note: individual users cannot use this API to query SMS signatures. For more information, please see [Identity Verification Overview](https://cloud.tencent.com/document/product/378/3629).
 
         :param request: Request instance for DescribeSmsSignList.
         :type request: :class:`tencentcloud.sms.v20190711.models.DescribeSmsSignListRequest`
@@ -194,7 +196,7 @@ class SmsClient(AbstractClient):
 
 
     def DescribeSmsTemplateList(self, request):
-        """>⚠️注意：个人认证用户不支持使用 API 查询短信正文模版，请参阅了解 [实名认证基本介绍](https://cloud.tencent.com/document/product/378/3629)。
+        """>⚠️ Note: individual users cannot use this API to query SMS body templates. For more information, please see [Identity Verification Overview](https://cloud.tencent.com/document/product/378/3629).
 
         :param request: Request instance for DescribeSmsTemplateList.
         :type request: :class:`tencentcloud.sms.v20190711.models.DescribeSmsTemplateListRequest`
@@ -222,7 +224,9 @@ class SmsClient(AbstractClient):
 
 
     def ModifySmsSign(self, request):
-        """This API is used to modify an SMS signature.
+        """This API is used to modify an SMS signature. Please read the [Tencent Cloud SMS Signature Review Standards](https://cloud.tencent.com/document/product/382/39022) before making a modification.
+        >- ⚠️ Note: individual users cannot use this API to modify SMS signatures. For more information, please see [Identity Verification Overview](https://cloud.tencent.com/document/product/378/3629). If your account identity is individual, you can log in to the console to modify SMS signatures.
+        >- Modifications can be made only if the signature status is **pending review** or **rejected**. **Approved** signatures cannot be modified.
 
         :param request: Request instance for ModifySmsSign.
         :type request: :class:`tencentcloud.sms.v20190711.models.ModifySmsSignRequest`
@@ -250,7 +254,9 @@ class SmsClient(AbstractClient):
 
 
     def ModifySmsTemplate(self, request):
-        """This API is used to modify an SMS template.
+        """This API is used to modify an SMS body template. Please read the [Tencent Cloud SMS Body Template Review Standards](https://cloud.tencent.com/document/product/382/39023) before making a modification.
+        >- ⚠️ Note: individual users cannot use this API to modify SMS body templates. For more information, please see [Identity Verification Overview](https://cloud.tencent.com/document/product/378/3629). If your account identity is individual, you can log in to the console to modify SMS body templates.
+        >- Modifications can be made only if the body template status is **pending review** or **rejected**. **Approved** body templates cannot be modified.
 
         :param request: Request instance for ModifySmsTemplate.
         :type request: :class:`tencentcloud.sms.v20190711.models.ModifySmsTemplateRequest`
